@@ -1,10 +1,11 @@
-# from .Phase import Phase
-from typing import Dict
-from pyPhases.storage.Storage import Storage
+import json
+
 from pyPhases.Data import Data, DataNotFound
-from pyPhases.Stage import Stage
-from pyPhases.Phase import Phase
 from pyPhases.decorator.ExportValidator import ExportValidator
+from pyPhases.Phase import Phase
+from pyPhases.Stage import Stage
+from pyPhases.storage.Storage import Storage
+from pyPhases.util.EventBus import EventBus
 from pyPhases.util.Logger import Logger
 from pyPhases.util.Optionizable import Optionizable
 
@@ -13,7 +14,7 @@ class ConfigNotFoundException(Exception):
     pass
 
 
-class Project(Optionizable):
+class Project(Optionizable, EventBus):
     """
     Represents a whole project with several phases
 
@@ -241,6 +242,7 @@ class Project(Optionizable):
 
     def setConfig(self, name: str, value):
         self.config[name] = value
+        self.trigger("configChanged", name)
 
     def getConfig(self, name: str) -> str:
         if not name in self.config:
@@ -250,6 +252,28 @@ class Project(Optionizable):
             )
         return self.config[name]
 
+    def saveConfig(self, path: str):
+        """Save the current project configuration to a JSON file.
+
+        Args:
+            path (str): filepath for the json file
+        """
+        with open(path, "w+") as f:
+            self.log("save config from file %s" % path)
+            json.dump(self.config, f)
+
+    def loadConfig(self, path: str):
+        """Load project configuration from a JSON file .
+
+        Args:
+            path (str): filepath for the json file
+        """
+        with open(path, "rb") as f:
+            self.log("load config from file %s" % path)
+            config = json.loads(f.read())
+            self.config.update(config)
+            self.trigger("configChanged", None)
+
     def addConfig(self, config) -> None:
         for name in config:
             if name in self.config:
@@ -304,6 +328,8 @@ class Project(Optionizable):
         else:
             self.runStageOrPhase(stageOrPhaseName)
 
+        self.trigger("afterRun")
+
     def runPhase(self, phase: Phase):
         phase.run()
 
