@@ -25,8 +25,11 @@ class DataExporter(Optionizable):
     def stream(self, data, options = {}):
         raise Exception("The exporter has no stream method implemented")
 
+    def finishStream(self, dataId):
+        pass
+
     def reinit(self):
-        if self.recreate:
+        if not self.recreate:
             return self
         return type(self)(self.options)
 
