@@ -1,3 +1,4 @@
+from pathlib import Path
 from .Storage import Storage
 from ..Data import DataNotFound
 
@@ -8,8 +9,8 @@ class FileStorage(Storage):
             file = open(self.getPath(path), "rb")
             return file.read()
         except FileNotFoundError:
-            self.logDebug("Data was not found: %s (%s)"%(path, self.getPath(path)))
-            raise DataNotFound("Data was not found: %s"%(path))
+            self.logDebug("Data was not found: %s (%s)" % (path, self.getPath(path)))
+            raise DataNotFound("Data was not found: %s" % (path))
 
     def write(self, path, data):
         if isinstance(data, bytes):
@@ -19,3 +20,6 @@ class FileStorage(Storage):
         file = open(self.getPath(path), writeMode)
         file.write(data)
         file.close()
+
+    def exists(self, dataId):
+        return Path(self.getPath(dataId)).is_file()
