@@ -1,10 +1,10 @@
-from unittest.result import TestResult
-from pyPhases.test.BaseTest import TestCase
-from typing import Iterable
 import unittest
+from typing import Iterable
 from unittest.loader import TestLoader
 from unittest.suite import TestSuite
 
+from pyPhases.test.BaseTest import TestCase
+
 
 class TestRun(unittest.TestCase):
     phaseTests: Iterable[TestCase] = []
@@ -12,6 +12,9 @@ class TestRun(unittest.TestCase):
     def testAll(self):
         pass
 
+    def afterRun(self):
+        pass
+
     def countTestCases(self):
         return len(self.phaseTests)
 
@@ -22,4 +25,6 @@ class TestRun(unittest.TestCase):
         for testCase in self.phaseTests:
             tests = loader.loadTestsFromTestCase(testCase)
             testSuite.addTests(tests)
-        return testSuite.run(result)
+        results = testSuite.run(result)
+        self.afterRun()
+        return results
