@@ -1,8 +1,10 @@
 from ..util.Logger import classLogger
 
+
 class MissingOption(Exception):
     pass
 
+
 @classLogger
 class Optionizable:
     options = {}
@@ -14,10 +16,10 @@ class Optionizable:
             self.options[val] = options[val]
 
     def getOption(self, name):
-        if (not name in self.options):
+        if not name in self.options:
             raise MissingOption("The option '" + name + "' is missing")
 
         return self.options[name]
 
-    def initialOptions(self, defaultOptions = None):
+    def initialOptions(self, defaultOptions=None):
         return {}
